@@ -1,10 +1,10 @@
 package MooseX::Log::Log4perl::Easy;
 
-use Moose::Role;
+use Any::Moose 'Role';
 
 with 'MooseX::Log::Log4perl';
 
-our $VERSION = '0.41';
+our $VERSION = '0.43';
 
 sub log_fatal { local $Log::Log4perl::caller_depth += 1; return shift->logger->fatal(@_); }
 sub log_error { local $Log::Log4perl::caller_depth += 1; return shift->logger->error(@_); }
@@ -49,8 +49,8 @@ logmethods for all available levels to your class instance. Hence it is possible
 
 without having to access a seperate log attribute as in MooseX::Log::Log4perl;
 
-In case your app grows and you need more of the super-cow powers of Log4perl or simply don't want the additional
-methodes to clutter up your class you can simply replace all code C<< $self->log_LEVEL >> with
+In case your app grows and you need more of the super-cow powers of Log4perl or simply don't want the additional 
+methods to clutter up your class you can simply replace all code C<< $self->log_LEVEL >> with 
 C<< $self->log->LEVEL >>.
 
 You can use the following regex substitution to accomplish that:
@@ -125,7 +125,7 @@ Contributions from Tim Bunce C<< <TIMB@cpan.org> >>
 
 =head1 LICENCE AND COPYRIGHT
 
-Copyright (c) 2008-2010, Roland Lammel C<< <lammel@cpan.org> >>, http://www.quikit.at. Some rights reserved.
+Copyright (c) 2008-2011, Roland Lammel C<< <lammel@cpan.org> >>, http://www.quikit.at
 
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself. See L<perlartistic>.
